@@ -1,7 +1,7 @@
 package Bencher::Scenario::Allocations;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -41,11 +41,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::Allocations
+Bencher::Scenario::Allocations - Benchmark allocations
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::Allocations (from Perl distribution Bencher-Scenario-Allocations), released on 2016-01-05.
+This document describes version 0.03 of Bencher::Scenario::Allocations (from Perl distribution Bencher-Scenario-Allocations), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -163,24 +163,28 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m Allocations >>):
 
- +-----+---------------------------------------------+----------+----------+---------+---------+
- | seq | name                                        | rate     | time     | errors  | samples |
- +-----+---------------------------------------------+----------+----------+---------+---------+
- | 9   | {dataset=>undef,participant=>"1k-hash100"}  | 102      | 9.77ms   | 1.1e-05 | 20      |
- | 8   | {dataset=>undef,participant=>"1k-array100"} | 470      | 2.13ms   | 1.7e-06 | 21      |
- | 7   | {dataset=>undef,participant=>"1k-hash10"}   | 9.1e+02  | 1.1ms    | 5.8e-06 | 20      |
- | 5   | {dataset=>undef,participant=>"1k-hash5"}    | 1.73e+03 | 0.579ms  | 1.7e-06 | 21      |
- | 6   | {dataset=>undef,participant=>"1k-array10"}  | 2.42e+03 | 0.412ms  | 9.1e-07 | 20      |
- | 4   | {dataset=>undef,participant=>"1k-array5"}   | 3.33e+03 | 0.3ms    | 2.1e-07 | 20      |
- | 3   | {dataset=>undef,participant=>"1k-hash1"}    | 3.72e+03 | 0.269ms  | 2.1e-07 | 20      |
- | 2   | {dataset=>undef,participant=>"1k-array1"}   | 4899     | 0.2041ms | 4.9e-08 | 24      |
- | 1   | {dataset=>undef,participant=>"1k-hash0"}    | 6.79e+03 | 0.147ms  | 1.6e-07 | 21      |
- | 0   | {dataset=>undef,participant=>"1k-array0"}   | 7.4e+03  | 0.135ms  | 5.3e-08 | 20      |
- +-----+---------------------------------------------+----------+----------+---------+---------+
+ +-------------+-----------+-----------+------------+---------+---------+
+ | participant | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-------------+-----------+-----------+------------+---------+---------+
+ | 1k-hash100  |    150    | 6.7       |     1      | 2.1e-05 |      20 |
+ | 1k-array100 |    672    | 1.49      |     4.53   | 2.3e-07 |      26 |
+ | 1k-hash10   |   1320    | 0.76      |     8.86   | 2.1e-07 |      20 |
+ | 1k-hash5    |   2260    | 0.442     |    15.2    | 5.3e-08 |      20 |
+ | 1k-array10  |   3534.38 | 0.282935  |    23.8105 | 4.5e-11 |      20 |
+ | 1k-array5   |   4750    | 0.211     |    32      | 5.1e-08 |      22 |
+ | 1k-hash1    |   4856.11 | 0.205926  |    32.7148 | 3.5e-11 |      20 |
+ | 1k-array1   |   6800    | 0.15      |    46      | 3.4e-07 |      31 |
+ | 1k-hash0    |   9957.38 | 0.100428  |    67.0812 |   0     |      20 |
+ | 1k-array0   |  11305.6  | 0.0884515 |    76.1641 |   0     |      20 |
+ +-------------+-----------+-----------+------------+---------+---------+
+
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
 
 =head1 HOMEPAGE
 
